# Namada Python package

Do you want us to build a complete Namada Python package?
Well, all we need is your support with the expedition.

**pip install namada <br>**

Docs: https://github.com/qmine/namada/tree/main/app <br>
PYPI: https://pypi.org/project/namada/ <br>
Namada Website: https://namada.net/ <br>
